# Generated by roxygen2: do not edit by hand

S3method(coef,rem_clogit)
S3method(print,llm_provider)
S3method(print,rem_cfg)
S3method(print,rem_clogit)
S3method(print,rem_covariates)
S3method(print,rem_sep)
export(attach_covariates_df)
export(compare_rem_models)
export(compute_hazard_surface)
export(compute_seq_stat_means)
export(cov_dyad_static)
export(cov_dyad_temporal)
export(cov_node_static)
export(cov_node_temporal)
export(fit_rem)
export(fit_rem_sep)
export(llm_call)
export(llm_provider_anthropic)
export(llm_provider_bedrock)
export(llm_provider_gemini)
export(llm_provider_grok)
export(llm_provider_mock)
export(llm_provider_ollama)
export(llm_provider_openai)
export(llm_provider_openai_compat)
export(make_behavior_queries)
export(make_query_predict)
export(make_query_roleplay_random)
export(make_query_roleplay_sender)
export(make_stat_means)
export(make_suffstats)
export(mock_strategy_highest_indegree)
export(mock_strategy_max_id)
export(mock_strategy_min_id)
export(prepare_edgelist)
export(rem_cfg)
export(rem_covariates)
export(run_llm_rem)
export(run_multiagent_rem)
importFrom(Rcpp,sourceCpp)
importFrom(stats,aggregate)
importFrom(stats,coef)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,setNames)
importFrom(stats,terms)
useDynLib(llrem, .registration = TRUE)
