#' @useDynLib llrem, .registration = TRUE
#' @importFrom Rcpp sourceCpp
#' @importFrom stats aggregate coef median model.matrix setNames terms
NULL

# Suppress R CMD check NOTE for ggplot2 aes() variables in compare_rem_models
utils::globalVariables(c("coef", "term", "lower95", "upper95"))
