# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

build_adjacency <- function(senders, receivers) {
    .Call(`_llrem_build_adjacency`, senders, receivers)
}

triadic_counts <- function(adj, rs_senders, rs_receivers) {
    .Call(`_llrem_triadic_counts`, adj, rs_senders, rs_receivers)
}

