% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/covariates.R
\name{cov_dyad_temporal}
\alias{cov_dyad_temporal}
\title{Create a temporal dyad-level covariate}
\usage{
cov_dyad_temporal(name, data, warn_missing = TRUE)
}
\arguments{
\item{name}{Character scalar.}

\item{data}{Data frame with columns \code{sender}, \code{receiver}, \code{time_start},
and \code{value}. Rows need not be sorted.}

\item{warn_missing}{Logical.}
}
\value{
An object of class \code{c("cov_dyad_temporal", "rem_cov")}.
}
\description{
Like \code{\link[=cov_dyad_static]{cov_dyad_static()}} but values change at known time breakpoints.
}
\examples{
treaty <- data.frame(
  sender = c(1L, 1L), receiver = c(2L, 2L),
  time_start = c(0, 15), value = c(0, 1)
)
cov <- cov_dyad_temporal("Treaty", treaty)
}
