% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{n_nodes}
\alias{n_nodes}
\title{Number of nodes in the MID edgelist}
\format{
An integer scalar.
}
\source{
Derived from the MID dataset bundled in this package.
}
\usage{
data(n_nodes)
}
\description{
Total number of unique country nodes in the bundled MID conflict edgelist
(95 countries).
}
\keyword{datasets}
