% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/covariates.R
\name{rem_covariates}
\alias{rem_covariates}
\title{Collect covariate objects for use in fit_rem}
\usage{
rem_covariates(...)
}
\arguments{
\item{...}{Any number of objects created by \code{\link[=cov_node_static]{cov_node_static()}},
\code{\link[=cov_node_temporal]{cov_node_temporal()}}, \code{\link[=cov_dyad_static]{cov_dyad_static()}}, or \code{\link[=cov_dyad_temporal]{cov_dyad_temporal()}}.}
}
\value{
An object of class \code{"rem_covariates"}.
}
\description{
Validates that all covariate names are unique, do not collide with
endogenous REM column names, and are proper \code{rem_cov} objects.
}
\examples{
gdp  <- cov_node_static("GDP", data.frame(node = 1:4, value = c(1,2,1,3)))
ally <- cov_dyad_static("Alliance",
          data.frame(sender = 1L, receiver = 2L, value = 1))
covs <- rem_covariates(gdp, ally)
}
